@@ -290,7 +290,7 @@ class Controller(Observer):
         self.user = self.api.verify_credentials()
 
         # initialize the timelines
-        self.info_message(_('Initializing timelines'))
+        self.info_message(_('Fetching timelines'))
 
         for timeline in self.timelines:
             timeline.update()
@@ -330,6 +330,10 @@ class Controller(Observer):
             self.error_message(_('API error: %s' % message))
             # recover from API errors
             self.main_loop()
+        except KeyboardInterrupt:
+            # treat Ctrl-C as Escape
+            self.key_handler.handle('esc')
+            self.main_loop()
 
     def exit(self):
         """Exit the program."""
